![Esbonio logo](https://github.com/swyddfa/esbonio/blob/release/resources/io.github.swyddfa.Esbonio.svg?raw=true)
# Esbonio

[![PyPI](https://img.shields.io/pypi/v/esbonio?style=flat-square)](https://pypi.org/project/esbonio)[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/esbonio?style=flat-square)](https://pypi.org/project/esbonio)![PyPI - Downloads](https://img.shields.io/pypi/dm/esbonio?style=flat-square)[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://github.com/swyddfa/esbonio/blob/develop/lib/esbonio/LICENSE)

**esbonio - (v.) to explain**

A [Language Server](https://microsoft.github.io/language-server-protocol/) that aims to make it easier to work with [reStructuredText](https://docutils.sourceforge.io/rst.html) tools such as [Sphinx](https://www.sphinx-doc.org/en/master/)

The language server provides the following features

## Completion

![Completion Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/completion-demo.gif)

## Definitions

![Definition Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/definition-demo.png)

## Diagnostics

![Diagnostics Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/diagnostic-sphinx-errors-demo.png)

## Document Links

![Document Link Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/document-links-demo.png)

## Document & Workspace Symbols

![Document & Workspace Symbol Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/document-workspace-symbols-demo.png)

## Hover

![Hover Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/hover-demo.png)

## Implementations

![Implementations Demo](https://github.com/swyddfa/esbonio/raw/release/resources/images/implementation-demo.gif)

## Installation

It's recommended to install the language server with [`pipx`](https://pipx.pypa.io/stable/)

Be sure to check out the [Getting Started](https://docs.esbon.io/en/latest/lsp/getting-started.html) guide for details on integrating the server with your editor of choice.

```
$ pipx install esbonio
```
